@@ -3,10 +3,6 @@ from collections.abc import Sequence
 from typing import Any, Optional, Protocol
 
 
-class Module(Protocol):
-    paramstyle: str
-
-
 class Cursor(Protocol):
     @property
     def description(
@@ -14,9 +10,6 @@ class Cursor(Protocol):
     ) -> Sequence[tuple[str, int, Optional[int], Optional[int], Optional[int], Optional[bool]]]:
         ...
 
-    def close(self) -> None:
-        ...
-
     def execute(self, operation: str, parameters: Sequence[Any] = ...) -> Any:
         ...
 
@@ -25,17 +18,3 @@ class Cursor(Protocol):
 
     def fetchall(self) -> Sequence[Sequence[Any]]:
         ...
-
-
-class Connection(Protocol):
-    def cursor(self) -> Cursor:
-        ...
-
-    def close(self) -> None:
-        ...
-
-    def commit(self) -> None:
-        ...
-
-    def rollback(self) -> None:
-        ...
